@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -71,9 +71,7 @@ bool TransportPluginManagerPrivate::initializePlugins()
     if (!mPluginList.isEmpty()) {
         return true;
     }
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("mailtransport"), [](const KPluginMetaData &md) {
-        return md.serviceTypes().contains(QLatin1String("MailTransport/Plugin"));
-    });
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("mailtransport"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
@@ -150,8 +148,10 @@ QVector<MailTransport::TransportAbstractPlugin *> TransportPluginManager::plugin
 
 MailTransport::TransportAbstractPlugin *TransportPluginManager::plugin(const QString &identifier)
 {
-    for (MailTransport::TransportAbstractPlugin *p : pluginsList()) {
-        for (const MailTransport::TransportAbstractPluginInfo &info : p->names()) {
+    const QVector<MailTransport::TransportAbstractPlugin *> lstPlugins = pluginsList();
+    for (MailTransport::TransportAbstractPlugin *p : lstPlugins) {
+        const QVector<TransportAbstractPluginInfo> lstPluginInfo = p->names();
+        for (const MailTransport::TransportAbstractPluginInfo &info : lstPluginInfo) {
             if (info.identifier == identifier) {
                 return p;
             }
