@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -20,7 +20,7 @@
 #include "akonadimailtransportplugin.h"
 #include "resourcesendjob_p.h"
 #include "mailtransportplugin_akonadi_debug.h"
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 #include <AkonadiCore/AgentManager>
 #include <MailTransport/TransportAbstractPlugin>
 #include <AkonadiCore/AgentInstanceCreateJob>
